<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="117"/>
        <source>Search...</source>
        <translation>Пошук...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="127"/>
        <source>Show/hide main menu</source>
        <translation>Показати/сховати головне меню</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="530"/>
        <source>Add to desktop</source>
        <translation>Додати стільницю</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="538"/>
        <source>Question</source>
        <translation>Питання</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="539"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Файл з такою назвою вже існує.
Хочете перезаписати його?</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="545"/>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="546"/>
        <source>The file cannot be overwritten.</source>
        <translation>Файл не можна перезаписати.</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="552"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu Settings</source>
        <translation>Налаштування головного меню</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Піктограма:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Текст кнопки:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Власний розмір шрифту:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Файл меню</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Файл меню:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>Найбільша довжина елемента:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Показати відповідні входження:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>Показати максимально:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Фільтрувати меню входжень</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Приховати меню входжень під час пошуку</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Очищати пошук перед показом меню</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Клавіатурне скорочення</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Натисніть кнопку, щоб змінити клавіатурне скорочення:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="76"/>
        <source>Reset</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="176"/>
        <source>Choose icon file</source>
        <translation>Вибрати файл піктограми</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="178"/>
        <source>Images (*.svg *.png)</source>
        <translation>Зображення (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="190"/>
        <source>Choose menu file</source>
        <translation>Оберіть файл меню</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="192"/>
        <source>Menu files (*.menu)</source>
        <translation>Файли меню (*.menu)</translation>
    </message>
</context>
</TS>
